==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/ServletDelaySpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ServletDelaySpecFluentImpl<A extends ServletDelaySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ServletDelaySpecFluent<A> {

    private String method;
    private Integer offset;
    private String querystring;
    private String requestpath;
    private Integer time;

    public ServletDelaySpecFluentImpl() {
    }

    public ServletDelaySpecFluentImpl(ServletDelaySpec instance) {
        this.withMethod(instance.getMethod()); 
        this.withOffset(instance.getOffset()); 
        this.withQuerystring(instance.getQuerystring()); 
        this.withRequestpath(instance.getRequestpath()); 
        this.withTime(instance.getTime()); 
    }

    public String getMethod() {
        return this.method;
    }

    public A withMethod(String method) {
        this.method=method; return (A) this;
    }

    public Boolean hasMethod() {
        return this.method != null;
    }

    public A withNewMethod(String arg1) {
        return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(StringBuilder arg1) {
        return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(StringBuffer arg1) {
        return (A)withMethod(new String(arg1));
    }

    public Integer getOffset() {
        return this.offset;
    }

    public A withOffset(Integer offset) {
        this.offset=offset; return (A) this;
    }

    public Boolean hasOffset() {
        return this.offset != null;
    }

    public A withNewOffset(String arg1) {
        return (A)withOffset(new Integer(arg1));
    }

    public A withNewOffset(int arg1) {
        return (A)withOffset(new Integer(arg1));
    }

    public String getQuerystring() {
        return this.querystring;
    }

    public A withQuerystring(String querystring) {
        this.querystring=querystring; return (A) this;
    }

    public Boolean hasQuerystring() {
        return this.querystring != null;
    }

    public A withNewQuerystring(String arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public A withNewQuerystring(StringBuilder arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public A withNewQuerystring(StringBuffer arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public String getRequestpath() {
        return this.requestpath;
    }

    public A withRequestpath(String requestpath) {
        this.requestpath=requestpath; return (A) this;
    }

    public Boolean hasRequestpath() {
        return this.requestpath != null;
    }

    public A withNewRequestpath(String arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public A withNewRequestpath(StringBuilder arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public A withNewRequestpath(StringBuffer arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public Integer getTime() {
        return this.time;
    }

    public A withTime(Integer time) {
        this.time=time; return (A) this;
    }

    public Boolean hasTime() {
        return this.time != null;
    }

    public A withNewTime(String arg1) {
        return (A)withTime(new Integer(arg1));
    }

    public A withNewTime(int arg1) {
        return (A)withTime(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ServletDelaySpecFluentImpl that = (ServletDelaySpecFluentImpl) o;
        if (method != null ? !method.equals(that.method) :that.method != null) return false;
        if (offset != null ? !offset.equals(that.offset) :that.offset != null) return false;
        if (querystring != null ? !querystring.equals(that.querystring) :that.querystring != null) return false;
        if (requestpath != null ? !requestpath.equals(that.requestpath) :that.requestpath != null) return false;
        if (time != null ? !time.equals(that.time) :that.time != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(method,  offset,  querystring,  requestpath,  time,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/ServletDelaySpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ServletDelaySpecFluentImpl<A extends ServletDelaySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ServletDelaySpecFluent<A> {

    private String method;
    private Integer offset;
    private String querystring;
    private String requestpath;
    private Integer time;

    public ServletDelaySpecFluentImpl() {
    }

    public ServletDelaySpecFluentImpl(ServletDelaySpec instance) {
        this.withMethod(instance.getMethod()); 
        this.withOffset(instance.getOffset()); 
        this.withQuerystring(instance.getQuerystring()); 
        this.withRequestpath(instance.getRequestpath()); 
        this.withTime(instance.getTime()); 
    }

    public String getMethod() {
        return this.method;
    }

    public A withMethod(String method) {
        this.method=method; return (A) this;
    }

    public Boolean hasMethod() {
        return this.method != null;
    }

    public A withNewMethod(StringBuilder arg1) {
        return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(int[] arg1,int arg2,int arg3) {
        return (A)withMethod(new String(arg1, arg2, arg3));
    }

    public A withNewMethod(char[] arg1) {
        return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(StringBuffer arg1) {
        return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(byte[] arg1,int arg2) {
        return (A)withMethod(new String(arg1, arg2));
    }

    public A withNewMethod(byte[] arg1) {
        return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(char[] arg1,int arg2,int arg3) {
        return (A)withMethod(new String(arg1, arg2, arg3));
    }

    public A withNewMethod(byte[] arg1,int arg2,int arg3) {
        return (A)withMethod(new String(arg1, arg2, arg3));
    }

    public A withNewMethod(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMethod(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMethod(String arg1) {
        return (A)withMethod(new String(arg1));
    }

    public Integer getOffset() {
        return this.offset;
    }

    public A withOffset(Integer offset) {
        this.offset=offset; return (A) this;
    }

    public Boolean hasOffset() {
        return this.offset != null;
    }

    public A withNewOffset(int arg0) {
        return (A)withOffset(new Integer(arg0));
    }

    public String getQuerystring() {
        return this.querystring;
    }

    public A withQuerystring(String querystring) {
        this.querystring=querystring; return (A) this;
    }

    public Boolean hasQuerystring() {
        return this.querystring != null;
    }

    public A withNewQuerystring(StringBuilder arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public A withNewQuerystring(int[] arg1,int arg2,int arg3) {
        return (A)withQuerystring(new String(arg1, arg2, arg3));
    }

    public A withNewQuerystring(char[] arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public A withNewQuerystring(StringBuffer arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public A withNewQuerystring(byte[] arg1,int arg2) {
        return (A)withQuerystring(new String(arg1, arg2));
    }

    public A withNewQuerystring(byte[] arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public A withNewQuerystring(char[] arg1,int arg2,int arg3) {
        return (A)withQuerystring(new String(arg1, arg2, arg3));
    }

    public A withNewQuerystring(byte[] arg1,int arg2,int arg3) {
        return (A)withQuerystring(new String(arg1, arg2, arg3));
    }

    public A withNewQuerystring(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withQuerystring(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewQuerystring(String arg1) {
        return (A)withQuerystring(new String(arg1));
    }

    public String getRequestpath() {
        return this.requestpath;
    }

    public A withRequestpath(String requestpath) {
        this.requestpath=requestpath; return (A) this;
    }

    public Boolean hasRequestpath() {
        return this.requestpath != null;
    }

    public A withNewRequestpath(StringBuilder arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public A withNewRequestpath(int[] arg1,int arg2,int arg3) {
        return (A)withRequestpath(new String(arg1, arg2, arg3));
    }

    public A withNewRequestpath(char[] arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public A withNewRequestpath(StringBuffer arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public A withNewRequestpath(byte[] arg1,int arg2) {
        return (A)withRequestpath(new String(arg1, arg2));
    }

    public A withNewRequestpath(byte[] arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public A withNewRequestpath(char[] arg1,int arg2,int arg3) {
        return (A)withRequestpath(new String(arg1, arg2, arg3));
    }

    public A withNewRequestpath(byte[] arg1,int arg2,int arg3) {
        return (A)withRequestpath(new String(arg1, arg2, arg3));
    }

    public A withNewRequestpath(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withRequestpath(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewRequestpath(String arg1) {
        return (A)withRequestpath(new String(arg1));
    }

    public Integer getTime() {
        return this.time;
    }

    public A withTime(Integer time) {
        this.time=time; return (A) this;
    }

    public Boolean hasTime() {
        return this.time != null;
    }

    public A withNewTime(int arg0) {
        return (A)withTime(new Integer(arg0));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ServletDelaySpecFluentImpl that = (ServletDelaySpecFluentImpl) o;
        if (method != null ? !method.equals(that.method) :that.method != null) return false;
        if (offset != null ? !offset.equals(that.offset) :that.offset != null) return false;
        if (querystring != null ? !querystring.equals(that.querystring) :that.querystring != null) return false;
        if (requestpath != null ? !requestpath.equals(that.requestpath) :that.requestpath != null) return false;
        if (time != null ? !time.equals(that.time) :that.time != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(method,  offset,  querystring,  requestpath,  time,  super.hashCode());
    }

}
